@@ -55,7 +55,10 @@ def check_files():
     if a == True:
         tkinter.messagebox.showinfo('提示','所有文件都可以被找到')
     else:
-        tkinter.messagebox.showerror('错误','model.dll文件缺失，重新安装本程序可能会解决问题')
+        try:
+            os.rename('model.py','model.dll')
+        except:
+            tkinter.messagebox.showerror('错误', 'model.dll文件缺失，重新安装本程序可能会解决问题')
 
 def fix_files():
     a = os.path.exists('model.dll')
@@ -335,11 +338,20 @@ class Data(Dataset):
         return img,label
 
 
-
-
-
+a=0
 root.title('垃圾分类程序 version 10.0.0')
 root.geometry('1077x640')
+a_file=os.path.exists('model.dll')
+if a==0:
+    if a_file == True:
+        a=a+1
+    else:
+        try:
+            os.rename('model.py','model.dll')
+            a=a+1
+        except:
+            tkinter.messagebox.showerror('错误', 'model.dll文件缺失，重新安装本程序可能会解决问题')
+            a=a+1
 b1=Button(root,text='文件检查',height=3,width=18,command=check_files).place(x=100,y=20)
 b2=Button(root,text='文件缺失修复',height=3,width=18,command=fix_files).place(x=250,y=20)
 b3=Button(root,text='启动主程序并进行自动分类操作\n(默认路径.test1.jpg)',height=3,width=40,command=Test_model_old).place(x=100,y=100)
